Zweig
=====

.. image:: https://travis-ci.org/DasIch/zweig.png?branch=master
   :target: https://travis-ci.org/DasIch/zweig

Zweig provides several utilities for dealing with the `ast` module. It's
BSD licensed and tested under Python 2.7 and 3.3.


Take a look at the documentation_ for more information.

.. _documentation: https://zweig.readthedocs.org/en/latest/
